Rdocumentation
powered by
Learn R Programming
rfigshare (version 0.3.5)
fs_add_author: Add an author to an article by ID number
Description
Add an author to an article by ID number
Usage
fs_add_author(article_id, author_id, session = fs_get_auth())
Arguments
article_id
id number of an article on figshare
author_id
the id number of a registered figshare user (see
fs_author_search
)
session
(optional) the authentication credentials from
fs_auth
. If not provided, will attempt to load from cache.