Learn R Programming

rfigshare (version 0.2-6)

fs_add_authors: Add author to an article

Description

Add author to an article

Usage

fs_add_authors(article_id, authors,
    session = fs_get_auth(), create_missing = FALSE)

Arguments

article_id
id number of an article on figshare
authors
a list or character string of authors or author id numbers (or mixed).
session
(optional) the authentication credentials from fs_auth. If not provided, will attempt to load from cache as long as figshare_auth has been run.
create_missing
(logical) Attempt to create authors not already registered on FigShare? (default is False and such authors will not be added). Not currently supported by the API(?)

Value

  • adds the requested authors to the given article

Examples

Run this code
fs_add_authors("138", list("Scott Chamberlain", "Karthik Ram"))
 fs_add_authors("138", c("Scott Chamberlain", "Karthik Ram"))
 fs_add_authors("138", list("Scott Chamberlain", "97306"))
 fs_add_authors("138", list("Scott Chamberlain", 97306))
 fs_add_authors(138, 97306)

Run the code above in your browser using DataLab