Learn R Programming

rfigshare (version 0.3.5)

fs_add_categories: Add a category to article

Description

Add a category to article

Usage

fs_add_categories(article_id, category_id, session = fs_get_auth(),
  debug = FALSE)

Arguments

article_id
the id number of the article
category_id
is a vector of integers corresponding to categories or a vector of category names
session
(optional) the authentication credentials from fs_auth. If not provided, will attempt to load from cache as long as figshare_auth has been run.
debug
return PUT results visibly?

Value

  • output of PUT request (invisibly)

References

http://api.figshare.com

See Also

fs_auth

Examples

Run this code
fs_add_categories(138, "Ecology")

Run the code above in your browser using DataLab