Learn R Programming

rfigshare (version 0.3.6)

fs_browse: Browse articles

Description

Browse can be set to all public articles, the users own articles, Browse can filter on matching timestamp, author, title, description, tag, category, and date range.

Usage

fs_browse(mine = TRUE, public_only = FALSE, private_only = FALSE,
  drafts_only = FALSE, session = fs_get_auth(),
  base = "http://api.figshare.com/v1", query = NA, debug = FALSE)

Arguments

mine
Logical, show only my (authenticated user's) articles. Defaults to TRUE.
public_only
(for use with mine=TRUE only) browse only my public articles. default is FALSE
private_only
(for use with mine=TRUE only) browse only my private articles. default is FALSE
drafts_only
(for use with mine=TRUE only) browse only my draft articles. default is FALSE
session
(optional) the authentication credentials from fs_auth. If not provided, will attempt to load from cache as long as figshare_auth has been run.
base
the API access url
query
a search query term (equivalent to calling fs_search)
debug
enable debugging mode

Value

  • output of PUT request (invisibly)

References

http://api.figshare.com/docs/howto.html#q-search

See Also

fs_auth

Examples

Run this code
fs_browse()

Run the code above in your browser using DataLab