Learn R Programming

rfigshare (version 0.3.7)

fs_cat_to_id: Helper function that matches string categories to id's

Description

Helper function that matches string categories to id's

Usage

fs_cat_to_id(category_id)

Arguments

category_id

Must be a valid category string, regardless of case

Value

a vector of integers corresponding to valid figshare categories

References

http://api.figshare.com