Learn R Programming

rfigshare (version 0.3.6)

fs_download: Get details for an article

Description

Get details for an article

Usage

fs_download(article_id, urls_only = TRUE, mine = is_mine(article_id),
  session = fs_get_auth(), show_versions = FALSE, version = NULL, ...)

Arguments

article_id
number
urls_only
logical (default TRUE) to only return the URLs to the downloadable objects but do not call download.file. If FALSE, will download files
mine
logical (default FALSE). Set to true to see article details for your own non-public articles
session
the authentication credentials from fs_auth
show_versions
logical, show what versions are available
version
show a given version number
...
additional arguments to download.file

References

http://api.figshare.com https://github.com/ropensci/rfigshare

See Also

fs_auth download.file

Examples

Run this code
url <- fs_download(90818)
data <- read.csv(url)
articles <- fs_search("SciFund")
ids <- fs_ids(articles)
fs_download(ids, urls_only=FALSE)

Run the code above in your browser using DataLab