Learn R Programming

rfigshare (version 0.3.5)

fs_make_public: Make an article public (for private or draft articles)

Description

Make an article public (for private or draft articles)

Usage

fs_make_public(article_id, session = fs_get_auth())

Arguments

article_id
the id number of the article
session
(optional) the authentication credentials from fs_auth.

Value

  • output of PUT request (invisibly)

Details

NOTE: Public articles are assigned DOIs and cannot be deleted or made private once declared public! Public articles do not count against your quota space.

References

http://api.figshare.com

See Also

fs_auth

Examples

Run this code
fs_make_public(123)

Run the code above in your browser using DataLab