Learn R Programming

rfigshare (version 0.3-0)

fs_new_article: Create a FigShare article.

Description

fs_new_article is a wrapper around many other rfigshare commands to provide convenient posting.

Usage

fs_new_article(title, description, type = c("dataset", "figure", "media", "poster", "paper", "fileset"), authors = NA, categories = NA, tags = NA, links = NA, files = NA, visibility = c("draft", "private", "public"), session = fs_get_auth())

Arguments

title
for the article, see fs_create for details.
description
of the article, see fs_create for details.
type
one of: dataset, figure, media, poster, or paper, see fs_create for details.
authors
Orded list of authors for the article, see fs_add_authors for details
categories
list of categories or category id numbers, see fs_add_categories for details.
tags
list of tags, see fs_add_tags for details.
links
list of links to add, see fs_add_links for details
files
path to the files to add, see fs_upload for details
visibility
one of "draft", "private" or "public". A draft document can still be edited and modified. A public document is visible to everyone and cannot be deleted (though additional authors to the work can still "claim" their authorship).
session
(optional) credentials, see link{fs_auth}

Value

article id

References

http://api.figshare.com

See Also

fs_auth, fs_add_categories, fs_add_authors, fs_add_tags, fs_add_links

Examples

Run this code
## Not run: 
# write.csv(mtcars, "mtcars.csv")
# id <- fs_new_article(title="A Test of rfigshare",
#                     description="This is a test of the fs_new_article function and related methods",
#                     type="dataset",
#                     authors=c("Karthik Ram", "Scott Chamberlain"),
#                     tags=c("ecology", "openscience"),
#                     categories="Ecology",
#                     links="http://ropensci.org",
#                     files="mtcars.csv",
#                     visibility="private")
# ## End(Not run)

Run the code above in your browser using DataLab