Learn R Programming

rfigshare (version 0.3.6)

fs_search: Advanced Search.

Description

Search function that will filter on matching timestamp, author, title, description, tag, category, and date range. Query searches against matches in any metadata field. Full-text searches coming soon.

Usage

fs_search(query, author = NA, title = NA, description = NA, tag = NA,
  category = NA, from_date = NA, to_date = NA, mine = FALSE,
  public_only = FALSE, private_only = FALSE, drafts_only = FALSE,
  session = fs_get_auth(), base = "http://api.figshare.com/v1",
  debug = FALSE)

Arguments

query
the search query
author
Show only results by this author
title
Show only results matching or partially matching this title
description
Show only results matching or partially matching this description
tag
Show only results matching this tag
category
Show only results matching this category
from_date
Start time window for search. Date format is YYYY-MM-DD
to_date
Ending time window for search. Date format is YYYY-MM-DD
mine
Browse only articles owned by user. default is FALSE. Not functional. Use fs_browse instead.
public_only
(for use with mine=TRUE only) browse only my public articles. default is FALSE
private_only
(for use with mine=TRUE only) browse only my private articles. default is FALSE
drafts_only
(for use with mine=TRUE only) browse only my draft articles. default is FALSE
session
(optional) the authentication credentials from fs_auth. If not provided, will attempt to load from cache as long as figshare_auth has been run.
base
the API access url
debug
logical, enable debugging mode

Value

  • output of PUT request (invisibly)

References

http://api.figshare.com/docs/howto.html#q-search

See Also

\code{fs_auth} fs_browse

Examples

Run this code
fs_search("Boettiger")
fs_search("Boettiger", author = "Carl")
fs_search("Boettiger", author = "Carl", from="2014-01-01")
fs_search("Boettiger", author = "Carl", from="2014-01-01",
          category = "Evolutionary Biology")

Run the code above in your browser using DataLab