Learn R Programming

rfigshare (version 0.3.6)

fs_add_links: Add link to article

Description

Adds url links to the metadata of an article

Usage

fs_add_links(article_id, link, session = fs_get_auth(), debug = FALSE)

Arguments

link
the url you wish to add (can be list of urls)
article_id
the id number of the article
session
(optional) the authentication credentials from fs_auth. If not provided, will attempt to load from cache as long as authentication has been run.
debug
logical, should function return details of PUT request?

Value

  • output of PUT request (invisibly)

References

http://api.figshare.com

See Also

fs_auth

Examples

Run this code
fs_add_links(138, list("http://carlboettiger.info", "http://ropensci.org"))

Run the code above in your browser using DataLab