(optional) the authentication credentials from fs_auth.
Value
output of PUT request (invisibly)
Details
NOTE: Public articles are assigned DOIs and cannot be deleted or made private once declared public! Public articles do not count against your quota space.