Usage
fs_search(query, author = NA, title = NA, description = NA, tag = NA,
category = NA, from_date = NA, to_date = NA, mine = FALSE,
public_only = FALSE, private_only = FALSE, drafts_only = FALSE,
session = fs_get_auth(), base = "http://api.figshare.com/v1",
debug = FALSE)
Arguments
author
Show only results by this author
title
Show only results matching or partially matching this title
description
Show only results matching or partially matching this description
tag
Show only results matching this tag
category
Show only results matching this category
from_date
Start time window for search. Date format is YYYY-MM-DD
to_date
Ending time window for search. Date format is YYYY-MM-DD
mine
Browse only articles owned by user. default is FALSE. Not functional. Use fs_browse instead. public_only
(for use with mine=TRUE only) browse only my public articles. default is FALSE
private_only
(for use with mine=TRUE only) browse only my private articles. default is FALSE
drafts_only
(for use with mine=TRUE only) browse only my draft articles. default is FALSE
session
(optional) the authentication credentials from fs_auth. If not provided, will attempt to load from cache as long as figshare_auth has been run. debug
logical, enable debugging mode